# SLC02-BP01: Agile & Scrum

Frameworks Agile và Scrum cho phát triển phần mềm.

## Agile Manifesto

```
┌─────────────────────────────────────────────────────────────┐
│                    Agile Manifesto                           │
│                                                              │
│   Individuals and interactions  OVER  processes and tools   │
│   Working software              OVER  comprehensive docs    │
│   Customer collaboration        OVER  contract negotiation  │
│   Responding to change          OVER  following a plan      │
└─────────────────────────────────────────────────────────────┘
```

## Scrum Framework

```
┌─────────────────────────────────────────────────────────────┐
│                    Scrum Framework                           │
│                                                              │
│  ROLES:    Product Owner │ Scrum Master │ Dev Team          │
│                                                              │
│  EVENTS:   Sprint │ Planning │ Daily │ Review │ Retro       │
│                                                              │
│  ARTIFACTS: Product Backlog │ Sprint Backlog │ Increment    │
└─────────────────────────────────────────────────────────────┘
```

## Scrum Roles

| Role | Trách nhiệm |
|------|-------------|
| **Product Owner** | Owns backlog, prioritizes work, stakeholder communication |
| **Scrum Master** | Facilitates events, removes blockers, coaches team |
| **Dev Team** | Delivers increments, self-organizing, cross-functional |

## Scrum Events

| Event | Mục đích | Thời gian |
|-------|----------|-----------|
| Sprint | Fixed time-box for delivery | 1-4 weeks |
| Sprint Planning | Plan work for sprint | Max 8 hours |
| Daily Scrum | Sync và plan daily work | 15 minutes |
| Sprint Review | Demo và get feedback | Max 4 hours |
| Sprint Retrospective | Improve process | Max 3 hours |

## Sprint Cycle

```
Sprint (1-4 weeks)
┌─────────────────────────────────────────────────────────────┐
│  ┌──────┐ → ┌──────┐ → ┌──────┐ → ┌──────┐ → ┌──────┐     │
│  │Plan  │   │Daily │   │Dev   │   │Review│   │Retro │     │
│  └──────┘   └──────┘   └──────┘   └──────┘   └──────┘     │
│  Day 1      Daily      Daily      Last Day   Last Day      │
└─────────────────────────────────────────────────────────────┘
```

## User Story Format

```
As a [type of user]
I want [functionality]
So that [benefit]

Acceptance Criteria:
- Given...When...Then...
```

## Velocity Tracking

```
Sprint 1: ████████████████ 32 points
Sprint 2: ████████████████████ 40 points
Sprint 3: ██████████████████ 36 points
Sprint 4: ████████████████████ 40 points

Average Velocity: 37 points/sprint
```

## Checklist

- [ ] Roles clearly defined
- [ ] All events conducted
- [ ] Backlog groomed regularly
- [ ] Definition of Done established
- [ ] Retrospective actions tracked
